@@ -3,29 +3,14 @@
 
     Handle Decoding of Content in to appropriate format from request as numpy array.
 
-    e.g. 
+    e.g.
         list of lists -> np.array.
 """
 import csv
 import io
 import json
-from PIL import Image
 import numpy as np
 
-from mldock.platform_helpers.mldock.inference import content_types
-
-def image_to_numpy(image_bytes):
-    """Convert an image bytes string into numpy through PIL.
-    Args:
-        bytes_like (str): bytes serialized image string.
-    Returns:
-        (np.array): Converted numpy array.
-    """
-    pillow_image =  Image.open(
-        io.BytesIO(image_bytes)
-    ).convert('L')
-    return np.asarray(pillow_image)
-
 def npy_to_numpy(npy_array):
     """Convert an NPY array into numpy.
     Args:
@@ -60,14 +45,12 @@ def csv_to_numpy(bytes_like):
     try:
         stream = io.StringIO(bytes_like.decode())
         reader = csv.reader(stream, delimiter=",", quotechar='"', doublequote=True, strict=True)
-        data = np.array([row for row in reader]).squeeze()
+        data = np.array(list(reader)).squeeze()
         return data
 
-    except ValueError as e:
-        if dtype is not None:
-            raise Exception(
-                "Error while writing numpy array: {}. dtype is: {}".format(e, dtype)
+    except Exception as exception:
+        raise Exception(
+            "Error while decoding csv: {EXCEPTION}".format(
+                EXCEPTION=exception
             )
-        raise
-    except Exception as e:
-        raise Exception("Error while decoding csv: {}".format(e))
+        ) from exception
